```text
                         _              __ 
                        | |            / _|
            __      ____| | __ _  __ _| |_ 
            \ \ /\ / / _` |/ _` |/ _` |  _|
             \ V  V / (_| | (_| | (_| | |  
              \_/\_/ \__,_|\__, |\__,_|_|  
                            __/ |          
                           |___/           
```

*We Do Give A Figure*

---

We do as we say : give a figure.  

WDGAF is a domain specific language built upon matplotlib with a focus on ease-of-use.

some terminology:

gaf : executable to *get a figure*  
fu  : figure-unfigured : source files containing description of the figure

### Quick Links

 - [Documentation](https://we-do-give-a-figure.readthedocs.io/)
 - [Source](https://github.com/rajp152k/Compilers-II)

## Installation

```bash
pip install WDGAF
```

That's it, you're ready to go.

## Usage

```bash
gaf <path/to/source.fu>
```

and now you get your figure ..

